@@ -1,4 +1,3 @@
-import plain.sessions.models
 from plain import models
 from plain.models import migrations
 
@@ -23,8 +22,5 @@ class Migration(migrations.Migration):
                     models.DateTimeField(),
                 ),
             ],
-            managers=[
-                ("objects", plain.sessions.models.SessionManager()),
-            ],
         ),
     ]
